module.exports = api => {
  const ENV = process.env.NODE_ENV || "development";
  const isProd = ENV === "production";
  const isTest = ENV === "test";
  api.cache(true);
  const presets = [
    isTest && [
      "@babel/preset-env",
      {
        targets: {
          node: "current"
        },
        useBuiltIns: "usage",
        corejs: 3
      }
    ],
    !isTest && [
      "@babel/preset-env",
      {
        useBuiltIns: "usage",
        corejs: 3,
        modules: false
      }
    ],
    [
      "@babel/react",
      {
        development: !isProd,
        useBuiltIns: true
      }
    ]
  ].filter(Boolean);
  const plugins = [
    [
      "@babel/proposal-class-properties",
      {
        loose: true
      }
    ],
    [
      "@babel/proposal-object-rest-spread",
      {
        useBuiltIns: true
      }
    ],
    [
      "@babel/plugin-transform-runtime",
      {
        corejs: false,
        helpers: false,
        regenerator: true,
        useESModules: !isTest
      }
    ]
  ].filter(Boolean);
  return {
    presets,
    plugins,
    sourceType: "unambiguous"
  };
};
